@@ -1,13 +1,14 @@
-#ifndef LIBDEFS_H
+#if !defined(__LIBDEFS_H)
 #define LIBDEFS_H
 
 /*
    {{{ includes 
  */
 
-#include <mutils.h>
-#include <mglobal.h>
-#include <mtypes.h>
+#include <mutils/mincludes.h>
+#include <mutils/mglobal.h>
+#include <mutils/mutils.h>
+#include <mutils/mtypes.h>
 
 #ifdef WIN32
 # define WIN32DLL_DEFINE __declspec( dllexport)
@@ -15,10 +16,6 @@
 # define WIN32DLL_DEFINE
 #endif
 
-#if !defined(byte)
-#define byte unsigned char
-#endif
-
 #define RAND32 (mutils_word32) ((mutils_word32)rand() << 17 ^ (mutils_word32)rand() << 9 ^ rand())
 
 #endif
