@@ -20,67 +20,26 @@
  */
 
 
-/* $Id: mhash.c,v 1.39 2005/01/12 20:58:53 imipak Exp $ */
+/* $Id: mhash.c,v 1.42 2006/01/10 04:40:48 imipak Exp $ */
 
 #include <libdefs.h>
 
 #include <mhash_int.h>
 
-#ifdef ENABLE_CRC32
-# include <mhash_crc32.h>
-#endif
-
-#ifdef ENABLE_HAVAL
-# include <mhash_haval.h>
-#endif
-
-#ifdef ENABLE_MD5
-# include <mhash_md5.h>
-#endif
-
-#ifdef ENABLE_MD4
-# include <mhash_md4.h>
-#endif
-
-#ifdef ENABLE_MD2
-# include <mhash_md2.h>
-#endif
-
-#ifdef ENABLE_SHA1
-# include <mhash_sha1.h>
-#endif
-
-#ifdef ENABLE_TIGER
-# include <mhash_tiger.h>
-#endif
-
-#ifdef ENABLE_RIPEMD
-# include <mhash_ripemd.h>
-#endif
-
-#ifdef ENABLE_SHA256_SHA224
-# include <mhash_sha256_sha224.h>
-#endif
-
-#ifdef ENABLE_SHA512_SHA384
-# include <mhash_sha512_sha384.h>
-#endif
-
-#ifdef ENABLE_ADLER32
-# include <mhash_adler32.h>
-#endif
-
-#ifdef ENABLE_GOST
-# include <mhash_gost.h>
-#endif
-
-#ifdef ENABLE_WHIRLPOOL
-# include <mhash_whirlpool.h>
-#endif
-
-#ifdef ENABLE_SNEFRU
-# include <mhash_snefru.h>
-#endif
+#include <mhash_crc32.h>
+#include <mhash_haval.h>
+#include <mhash_md5.h>
+#include <mhash_md4.h>
+#include <mhash_md2.h>
+#include <mhash_sha1.h>
+#include <mhash_tiger.h>
+#include <mhash_ripemd.h>
+#include <mhash_sha256_sha224.h>
+#include <mhash_sha512_sha384.h>
+#include <mhash_adler32.h>
+#include <mhash_gost.h>
+#include <mhash_whirlpool.h>
+#include <mhash_snefru.h>
 
 /* 19/03/2000 Changes for better thread handling --nikos 
  * Actually it is thread safe.
@@ -97,64 +56,64 @@
 struct mhash_hash_entry {
 	mutils_word8 *name;
 	hashid id;
-	size_t blocksize;
-	size_t hash_pblock;
+	mutils_word32 blocksize;
+	mutils_word32 hash_pblock;
 
-	size_t state_size;
+	mutils_word32 state_size;
 	INIT_FUNC init_func;
 	HASH_FUNC hash_func;
 	FINAL_FUNC final_func;
 	DEINIT_FUNC deinit_func;
 };
 
-static const mhash_hash_entry algorithms[] = {
-#ifdef ENABLE_CRC32
+static __const mhash_hash_entry algorithms[] = {
+#if defined(ENABLE_CRC32)
 	MHASH_ENTRY(MHASH_CRC32, 4, 0, sizeof(mutils_word32), mhash_clear_crc32, 
 		mhash_crc32, NULL, mhash_get_crc32),
 	MHASH_ENTRY(MHASH_CRC32B, 4, 0, sizeof(mutils_word32), mhash_clear_crc32,
 		mhash_crc32b, NULL, mhash_get_crc32),
 #endif
 
-#ifdef ENABLE_ADLER32
+#if defined(ENABLE_ADLER32)
 	MHASH_ENTRY(MHASH_ADLER32, 4, 0, sizeof(mutils_word32), mhash_clear_adler32, 
 		mhash_adler32, NULL, mhash_get_adler32),
 #endif
 
-#ifdef ENABLE_MD5
+#if defined(ENABLE_MD5)
 	MHASH_ENTRY(MHASH_MD5, 16, 64, sizeof(MD5_CTX), MD5Init,
 		MD5Update, NULL, MD5Final),
 #endif
 
-#ifdef ENABLE_MD4
+#if defined(ENABLE_MD4)
 	MHASH_ENTRY(MHASH_MD4, 16, 64, sizeof(MD4_CTX), MD4Init, 
 		MD4Update, NULL, MD4Final),
 #endif
 
-#ifdef ENABLE_MD2
+#if defined(ENABLE_MD2)
 	MHASH_ENTRY(MHASH_MD2, 16, 16, sizeof(MD2_CTX), md2_init,
 		md2_update, NULL, md2_digest),
 #endif
 
-#ifdef ENABLE_SHA1
+#if defined(ENABLE_SHA1)
 	MHASH_ENTRY(MHASH_SHA1, 20, 64, sizeof(SHA_CTX), sha_init, 
 		sha_update, sha_final, sha_digest),
 #endif
 
-#ifdef ENABLE_SHA256_SHA224
+#if defined(ENABLE_SHA256_SHA224)
 	MHASH_ENTRY(MHASH_SHA256, 32, 64, sizeof( SHA256_SHA224_CTX), sha256_init,
 		sha256_sha224_update, sha256_sha224_final, sha256_digest),
 	MHASH_ENTRY(MHASH_SHA224, 28, 64, sizeof( SHA256_SHA224_CTX), sha224_init,
 		sha256_sha224_update, sha256_sha224_final, sha224_digest),
 #endif
 
-#ifdef ENABLE_SHA512_SHA384
+#if defined(ENABLE_SHA512_SHA384)
 	MHASH_ENTRY(MHASH_SHA512, 64, 128, sizeof( SHA512_SHA384_CTX), sha512_init,
 		sha512_sha384_update, sha512_sha384_final, sha512_digest),
 	MHASH_ENTRY(MHASH_SHA384, 48, 128, sizeof( SHA512_SHA384_CTX), sha384_init,
 		sha512_sha384_update, sha512_sha384_final, sha384_digest),
 #endif
 
-#ifdef ENABLE_HAVAL
+#if defined(ENABLE_HAVAL)
 	MHASH_ENTRY(MHASH_HAVAL256, 32, 128, sizeof(havalContext), havalInit256,
 		havalUpdate, NULL, havalFinal),
 	MHASH_ENTRY(MHASH_HAVAL128, 16, 128, sizeof(havalContext), havalInit128,
@@ -167,7 +126,7 @@ static const mhash_hash_entry algorithms[] = {
 		havalUpdate, NULL, havalFinal),
 #endif
 
-#ifdef ENABLE_RIPEMD
+#if defined(ENABLE_RIPEMD)
 	MHASH_ENTRY(MHASH_RIPEMD128, 16, 64, sizeof(RIPEMD_CTX), ripemd128_init, 
 		ripemd_update, ripemd_final, ripemd_digest),
 	MHASH_ENTRY(MHASH_RIPEMD160, 20, 64, sizeof(RIPEMD_CTX), ripemd160_init, 
@@ -178,7 +137,7 @@ static const mhash_hash_entry algorithms[] = {
 		ripemd_update, ripemd_final, ripemd_digest),
 #endif
 
-#ifdef ENABLE_TIGER
+#if defined(ENABLE_TIGER)
 	MHASH_ENTRY(MHASH_TIGER, 24, 64, sizeof(TIGER_CTX), tiger_init, 
 		tiger_update, tiger_final, tiger_digest),
 	MHASH_ENTRY(MHASH_TIGER128, 16, 64, sizeof(TIGER_CTX), tiger_init,
@@ -187,17 +146,17 @@ static const mhash_hash_entry algorithms[] = {
 		tiger_update, tiger_final, tiger160_digest),
 #endif
 
-#ifdef ENABLE_GOST
+#if defined(ENABLE_GOST)
 	MHASH_ENTRY(MHASH_GOST, 32, 0, sizeof(GostHashCtx), gosthash_reset, 
 		gosthash_update, NULL, gosthash_final),
 #endif
 
-#ifdef ENABLE_WHIRLPOOL
+#if defined(ENABLE_WHIRLPOOL)
 	MHASH_ENTRY(MHASH_WHIRLPOOL, 64, 64, sizeof(WHIRLPOOL_CTX), whirlpool_init, 
 		    whirlpool_update, whirlpool_final, whirlpool_digest),
 #endif
 
-#ifdef ENABLE_SNEFRU
+#if defined(ENABLE_SNEFRU)
 	MHASH_ENTRY(MHASH_SNEFRU128, 16, 64, sizeof(SNEFRU_CTX), snefru_init, 
 		    snefru128_update, snefru128_final, snefru128_digest),
 	MHASH_ENTRY(MHASH_SNEFRU256, 32, 64, sizeof(SNEFRU_CTX), snefru_init, 
@@ -208,7 +167,7 @@ static const mhash_hash_entry algorithms[] = {
 };
 
 #define MHASH_LOOP(b) \
-	const mhash_hash_entry *p; \
+	__const mhash_hash_entry *p; \
 	for (p = algorithms; p->name != NULL; p++) { b ; }
 
 #define MHASH_ALG_LOOP(a) \
@@ -218,7 +177,7 @@ static const mhash_hash_entry algorithms[] = {
 # define MMAX(x,y) (x>y?x:y)
 #endif
 
-WIN32DLL_DEFINE size_t mhash_count(void)
+WIN32DLL_DEFINE mutils_word32 mhash_count(void)
 {
 	hashid count = 0;
 
@@ -227,22 +186,22 @@ WIN32DLL_DEFINE size_t mhash_count(void)
 	return count;
 }
 
-WIN32DLL_DEFINE size_t mhash_get_block_size(hashid type)
+WIN32DLL_DEFINE mutils_word32 mhash_get_block_size(hashid type)
 {
-	size_t ret = 0;
+	mutils_word32 ret = 0;
 
 	MHASH_ALG_LOOP(ret = p->blocksize);
 	return ret;
 }
 
-WIN32DLL_DEFINE size_t _mhash_get_state_size(hashid type)
+WIN32DLL_DEFINE mutils_word32 _mhash_get_state_size(hashid type)
 {
 	/* Fixed: Valid state sizes that exceeded maximum
 	   positive value for integer would be returned as
 	   an error.
 	*/
 
-	size_t size = 0;
+	mutils_word32 size = 0;
 
 	MHASH_ALG_LOOP(size = p->state_size);
 	return size;
@@ -294,7 +253,7 @@ WIN32DLL_DEFINE mutils_word8 *mhash_get_hash_name(hashid type)
 	return mutils_strdup(ret);
 }
 
-WIN32DLL_DEFINE const mutils_word8 *mhash_get_hash_name_static(hashid type)
+WIN32DLL_DEFINE __const mutils_word8 *mhash_get_hash_name_static(hashid type)
 {
 	mutils_word8 *ret = NULL;
 
@@ -341,7 +300,7 @@ MHASH ret;
 	return ret;
 }
 
-MHASH mhash_init_int(const hashid type)
+MHASH mhash_init_int(__const hashid type)
 {
 	MHASH ret;
 	INIT_FUNC func;
@@ -383,30 +342,9 @@ MHASH mhash_init_int(const hashid type)
 		
 }
 
-#define MIX32(a) \
-	(((mutils_word32)((mutils_word8 *)(a))[0]) | \
-	(((mutils_word32)((mutils_word8 *)(a))[1]) << 8)| \
-	(((mutils_word32)((mutils_word8 *)(a))[2]) << 16)| \
-	(((mutils_word32)((mutils_word8 *)(a))[3]) << 24))
-
-#ifdef WORDS_BIGENDIAN
-void mhash_32bit_conversion(mutils_word32 *ptr, size_t count)
-{
-	size_t i;
-	mutils_word32 *cptr = ptr;
-
-	for (i = 0; i < count; i++, cptr++)
-	{
-		cptr = MIX32(cptr);
-	}
-}
-#else
-#define mhash_32bit_conversion(a,b)
-#endif
-
 /* plaintext should be a multiple of the algorithm's block size */
 
-mutils_boolean mhash(MHASH td, const void *plaintext, size_t size)
+mutils_boolean mhash(MHASH td, __const void *plaintext, mutils_word32 size)
 {
 	
 	if (td->hash_func!=NULL)
@@ -435,7 +373,7 @@ WIN32DLL_DEFINE
 }
 
 WIN32DLL_DEFINE
-    void *mhash_end_m(MHASH td, void *(*hash_malloc) (size_t))
+    void *mhash_end_m(MHASH td, void *(*hash_malloc) (mutils_word32))
 {
 	void *digest;
 	mutils_word32 size;
@@ -452,11 +390,11 @@ WIN32DLL_DEFINE
 
 WIN32DLL_DEFINE void *mhash_end(MHASH td)
 {
-	return(mhash_end_m(td, malloc));
+	return(mhash_end_m(td, mutils_malloc));
 }
 
 
-WIN32DLL_DEFINE MHASH mhash_init(const hashid type)
+WIN32DLL_DEFINE MHASH mhash_init(__const hashid type)
 {
 	MHASH ret = MHASH_FAILED;
 
@@ -467,9 +405,9 @@ WIN32DLL_DEFINE MHASH mhash_init(const hashid type)
 
 /* HMAC functions */
 
-WIN32DLL_DEFINE size_t mhash_get_hash_pblock(hashid type)
+WIN32DLL_DEFINE mutils_word32 mhash_get_hash_pblock(hashid type)
 {
-	size_t ret = 0;
+	mutils_word32 ret = 0;
 
 	MHASH_ALG_LOOP(ret = p->hash_pblock);
 	return(ret);
@@ -540,7 +478,7 @@ WIN32DLL_DEFINE
 
 
 WIN32DLL_DEFINE
-    void *mhash_hmac_end_m(MHASH td, void *(*hash_malloc) (size_t))
+    void *mhash_hmac_end_m(MHASH td, void *(*hash_malloc) (mutils_word32))
 {
 	void *digest;
 
@@ -558,11 +496,11 @@ WIN32DLL_DEFINE
 
 WIN32DLL_DEFINE void *mhash_hmac_end(MHASH td)
 {
-	return mhash_hmac_end_m(td, malloc);
+	return mhash_hmac_end_m(td, mutils_malloc);
 }
 
 WIN32DLL_DEFINE
-    MHASH mhash_hmac_init(const hashid type, void *key, mutils_word32 keysize,
+    MHASH mhash_hmac_init(__const hashid type, void *key, mutils_word32 keysize,
 			  mutils_word32 block)
 {
 	MHASH ret = MHASH_FAILED;
@@ -623,6 +561,12 @@ WIN32DLL_DEFINE
 	return(ret);
 }
 
+WIN32DLL_DEFINE void mhash_free(void *ptr)
+{
+        mutils_free(ptr);
+}
+
+
 /*
   Saves the state of a hashing algorithm such that it can be
   restored at some later point in time using
@@ -707,7 +651,7 @@ WIN32DLL_DEFINE MHASH mhash_restore_state_mem(void* _mem)
 
 	if (ret->hmac_key_size != 0)
 	{
-		ret->hmac_key = malloc( ret->hmac_key_size);
+		ret->hmac_key = mutils_malloc(ret->hmac_key_size);
 		if (ret->hmac_key==NULL)
 			goto freeall;
 	
