@@ -22,7 +22,7 @@
 
 #define R 8  // number of rounds
 
-static const mutils_word32 SBOX[R * 256 * 2]= {
+static __const mutils_word32 SBOX[R * 256 * 2]= {
   0x64f9001bl, 0xfeddcdf6l, 0x7c8ff1e2l, 0x11d71514l, 0x8b8c18d3l, 0xdddf881el,
   0x6eab5056l, 0x88ced8e1l, 0x49148959l, 0x69c56fd5l, 0xb7994f03l, 0x0fbcee3el,
   0x3c264940l, 0x21557e58l, 0xe14b3fc2l, 0x2e5cf591l, 0xdceff8cel, 0x092a1648l,
@@ -724,10 +724,10 @@ void snefru_init(struct snefru_ctx *ctx)
  */
 static void snefru(mutils_word32 *block, int len)
 {
-  const int st[4] = {16, 8, 16, 24};
+  __const mutils_word32 st[4] = {16, 8, 16, 24};
   mutils_word32 isave[SNEFRU256_DIGEST_LEN];
   mutils_word32 *sbox, x;
-  int i, j;
+  mutils_word32 i, j;
 
   mutils_memcpy(isave, block, SNEFRU256_DIGEST_SIZE);
   
@@ -749,8 +749,8 @@ static void snefru(mutils_word32 *block, int len)
 
 static void processBuffer(struct snefru_ctx *ctx, int len)
 {
-  int i;
-  byte *buf = ctx->buffer;
+  mutils_word32 i;
+  mutils_word8 *buf = ctx->buffer;
 
   for(i = len; i < SNEFRU_BLOCK_LEN; i++) {
     ctx->hash[i] = 
@@ -765,11 +765,11 @@ static void processBuffer(struct snefru_ctx *ctx, int len)
 /**
  * Update the hashing state.
  */
-static void snefru_update(struct snefru_ctx *ctx, const byte *data, unsigned length,
-			  int data_size, int digest_len) 
+static void snefru_update(struct snefru_ctx *ctx, __const mutils_word8 *data, mutils_word32 length,
+			  mutils_word32 data_size, mutils_word32 digest_len) 
 {
   if (ctx->index) {	/* Try to fill partial block */
-    unsigned int left = data_size - ctx->index;
+    mutils_word32 left = data_size - ctx->index;
     if (length < left) {
       mutils_memcpy(ctx->buffer + ctx->index, data, length);
       ctx->index += length;
@@ -793,12 +793,12 @@ static void snefru_update(struct snefru_ctx *ctx, const byte *data, unsigned len
   ctx->index = length;
 }
 
-void snefru128_update(struct snefru_ctx *ctx, const byte *data, unsigned length)
+void snefru128_update(struct snefru_ctx *ctx, __const mutils_word8 *data, mutils_word32 length)
 {
   snefru_update(ctx, data, length, SNEFRU128_DATA_SIZE, SNEFRU128_DIGEST_LEN);
 }
 
-void snefru256_update(struct snefru_ctx *ctx, const byte *data, unsigned length)
+void snefru256_update(struct snefru_ctx *ctx, __const mutils_word8 *data, mutils_word32 length)
 {
   snefru_update(ctx, data, length, SNEFRU256_DATA_SIZE, SNEFRU256_DIGEST_LEN);
 }
@@ -845,9 +845,9 @@ void snefru256_final(struct snefru_ctx *ctx)
 }
 
 
-static void snefru_digest(const struct snefru_ctx *ctx, byte *digest, int len)
+static void snefru_digest(__const struct snefru_ctx *ctx, mutils_word8 *digest, mutils_word32 len)
 {
-  int i;
+  mutils_word32 i;
   for (i = 0; i < len; i++) {
     *digest++ = ctx->hash[i] >> 24;
     *digest++ = (ctx->hash[i] >> 16) & 0xff;
@@ -856,12 +856,12 @@ static void snefru_digest(const struct snefru_ctx *ctx, byte *digest, int len)
   }
 }
 
-void snefru128_digest(const struct snefru_ctx *ctx, byte *digest)
+void snefru128_digest(__const struct snefru_ctx *ctx, mutils_word8 *digest)
 {
   snefru_digest(ctx, digest, SNEFRU128_DIGEST_LEN);
 }
 
-void snefru256_digest(const struct snefru_ctx *ctx, byte *digest)
+void snefru256_digest(__const struct snefru_ctx *ctx, mutils_word8 *digest)
 {
   snefru_digest(ctx, digest, SNEFRU256_DIGEST_LEN);
 }
