@@ -32,8 +32,7 @@
 int main()
 {
 
-	mutils_word8 tmp[128];
-	mutils_word8 tmp2[3];
+	mutils_word8 *tmp;
 	mutils_word8 *password;
 	mutils_word32 passlen;
 	mutils_word8 *data;
@@ -59,14 +58,8 @@ int main()
 	mhash(td, data, datalen);
 	mac = mhash_hmac_end(td);
 
-	tmp2[2]='\0';
+	tmp = mutils_asciify(mac, mhash_get_block_size(MHASH_MD5));
 	
-	for (j = 0; j < mhash_get_block_size(MHASH_MD5); j++)
-	{
-		sprintf((char *) tmp2, "%2x", (char) mac[j]);
-		mutils_strcat(tmp, tmp2);
-	}
-
 	result = mutils_strcmp((mutils_word8 *) DIGEST1, tmp);
 
 	mutils_free(password);
@@ -74,12 +67,16 @@ int main()
 
 	if (result != 0) {
 		fprintf(stderr, "HMAC-Test: Failed\n");
-		fprintf(stderr, "Expecting: 0x%s\nGot: 0x%s\n", DIGEST1, tmp);
+		fprintf(stderr, "Digest size: %d\n", mhash_get_block_size(MHASH_MD5));
+		fprintf(stderr, "Expecting: 0x%s\n", DIGEST1);
+		fprintf(stderr, "Got: 0x%s\n", tmp);
 		return(MUTILS_INVALID_RESULT);
 	}
 
-	/* Test No 2 */	
+	mutils_free(tmp);
 
+	/* Test No 2 */	
+	
 	mutils_memset(tmp, 0, sizeof(tmp));
 	
 	passlen=sizeof(KEY2) - 1;
@@ -96,14 +93,8 @@ int main()
 	mhash(td, data, datalen);
 	mac = mhash_hmac_end(td);
 
-	tmp2[2]='\0';
+	tmp = mutils_asciify(mac, mhash_get_block_size(MHASH_MD5));
 	
-	for (j = 0; j < mhash_get_block_size(MHASH_MD5); j++)
-	{
-		sprintf((char *) tmp2, "%.2x", (char) mac[j]);
-		mutils_strcat(tmp, tmp2);
-	}
-
 	result = mutils_strcmp((mutils_word8 *) DIGEST2, tmp);
 
 	mutils_free(password);
@@ -118,5 +109,7 @@ int main()
 
 	fprintf(stderr, "MD5 HMAC-Test: Ok\n");
 
+	mutils_free(tmp);
+
 	return(MUTILS_OK);
 }
